@@ -110,7 +110,7 @@ on_about (GSimpleAction *action,
                            "comments", _("View and search logs"),
                            "copyright", "Copyright © 2013–2015 Red Hat, Inc.\nCopyright © 2014-2015 Jonathan Kang",
                            "license-type", GTK_LICENSE_GPL_3_0,
-                           "logo-icon-name", PACKAGE_TARNAME,
+                           "logo-icon-name", "org.gnome.Logs",
                            "version", PACKAGE_VERSION,
                            "website", PACKAGE_URL, NULL);
 }
@@ -196,12 +196,6 @@ gl_application_startup (GApplication *application)
     /* gtk_init() calls setlocale(), so gettext must be called after that. */
     g_set_application_name (_(PACKAGE_NAME));
     gtk_window_set_default_icon_name (PACKAGE_TARNAME);
-
-    /* Must register custom types before using them from GtkBuilder. */
-    gl_window_get_type ();
-    gl_category_list_get_type ();
-    gl_event_toolbar_get_type ();
-    gl_event_view_list_get_type ();
 }
 
 static void
